@@ -1,5 +1,5 @@
 package Geo::Coder::OpenCage;
-$Geo::Coder::OpenCage::VERSION = '0.12';
+$Geo::Coder::OpenCage::VERSION = '0.13';
 use strict;
 use warnings;
 use feature qw(say);
@@ -123,7 +123,7 @@ Geo::Coder::OpenCage
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -135,11 +135,11 @@ version 0.12
 
 This module provides an interface to the OpenCage geocoding service.
 
-For full details on the API visit L<https://geocoder.opencagedata.com/api>.
+For full details of the API visit L<https://geocoder.opencagedata.com/api>.
 
 =head1 NAME
 
-Geo::Coder::OpenCage - Geocode addresses with the OpenCage Geocoder API
+Geo::Coder::OpenCage - Geocode coordinates and addresses with the OpenCage Geocoder
 
 =head1 METHODS
 
@@ -147,7 +147,7 @@ Geo::Coder::OpenCage - Geocode addresses with the OpenCage Geocoder API
 
     my $Geocoder = Geo::Coder::OpenCage->new(api_key => $my_api_key);
 
-You can get your API key from https://geocoder.opencagedata.com
+Get your API key from L<https://geocoder.opencagedata.com>
 
 =head2 geocode
 
@@ -155,10 +155,9 @@ Takes a single named parameter 'location' and returns a result hashref.
 
     my $result = $Geocoder->geocode(location => "Mudgee, Australia");
 
-warns and returns undef if the query fails for some reason
+warns and returns undef if the query fails for some reason.
 
-The OpenCage Geocoder has a few optional parameters, some of which this module
-supports and some of which it doesn't.
+The OpenCage Geocoder has a few optional parameters
 
 =over 1
 
@@ -193,11 +192,6 @@ the ISO 3166-1 Alpha 2standard.
 
 =over 2
 
-=item format
-
-This module only ever uses the JSON format. For other formats you should access
-the API directly using HTTP::Tiny or similar user agent module.
-
 =item jsonp
 
 This module always parses the response as a Perl data structure, so the jsonp
@@ -221,7 +215,7 @@ Takes two named parameters 'lat' and 'lng' and returns a result hashref.
 
     my $result = $Geocoder->reverse_geocode(lat => -22.6792, lng => 14.5272);
 
-This supports the optional 'language' parameter in the same way that geocode() 
+This method supports the optional parameters in the same way that geocode() 
 does.
 
 =head1 ENCODING
